<?php

namespace SharzonTest\SharzonTest\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use SharzonTest\SharzonTest\Interfaces\SharzonTestRepositoryInterface;
use SharzonTest\SharzonTest\Repositories\Presenter\SharzonTestItemTransformer;

/**
 * Pubic API controller class.
 */
class SharzonTestPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \SharzonTest\SharzonTest\Interfaces\SharzonTestRepositoryInterface $sharzon_test
     *
     * @return type
     */
    public function __construct(SharzonTestRepositoryInterface $sharzon_test)
    {
        $this->repository = $sharzon_test;
        parent::__construct();
    }

    /**
     * Show sharzon_test's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $sharzon_tests = $this->repository
            ->setPresenter('\\SharzonTest\\SharzonTest\\Repositories\\Presenter\\SharzonTestListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $sharzon_tests['code'] = 2000;
        return response()->json($sharzon_tests)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show sharzon_test.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $sharzon_test = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($sharzon_test)) {
            $sharzon_test         = $this->itemPresenter($module, new SharzonTestItemTransformer);
            $sharzon_test['code'] = 2001;
            return response()->json($sharzon_test)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
