<?php

namespace SharzonTest\SharzonTest\Http\Controllers;
use Litepie\SharzonTest\Http\Requests\SharzonTestRequest;
use Litepie\SharzonTest\Models\SharzonTest;

trait SharzonTestWorkflow {
	
    /**
     * Workflow controller function for sharzon_test.
     *
     * @param Model   $sharzon_test
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(SharzonTestRequest $request, SharzonTest $sharzon_test, $step)
    {

        try {

            $sharzon_test->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('sharzon-test::sharzon_test.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/sharzon_test/sharzon_test/' . $sharzon_test->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/sharzon_test/sharzon_test/' . $sharzon_test->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for sharzon_test.
     *
     * @param Model   $sharzon_test
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(SharzonTest $sharzon_test, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $sharzon_test->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('sharzon-test::sharzon_test.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('sharzon-test::admin.sharzon_test.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('sharzon-test::admin.sharzon_test.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('sharzon-test::admin.sharzon_test.message', $data)->render();

        }

    }
}