<?php

namespace SharzonTest\SharzonTest\Policies;

use App\User;
use SharzonTest\SharzonTest\Models\SharzonTest;

class SharzonTestPolicy
{

    /**
     * Determine if the given user can view the sharzon_test.
     *
     * @param User $user
     * @param SharzonTest $sharzon_test
     *
     * @return bool
     */
    public function view(User $user, SharzonTest $sharzon_test)
    {
        if ($user->canDo('sharzon-test.sharzon_test.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $sharzon_test->user_id;
    }

    /**
     * Determine if the given user can create a sharzon_test.
     *
     * @param User $user
     * @param SharzonTest $sharzon_test
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('sharzon-test.sharzon_test.create');
    }

    /**
     * Determine if the given user can update the given sharzon_test.
     *
     * @param User $user
     * @param SharzonTest $sharzon_test
     *
     * @return bool
     */
    public function update(User $user, SharzonTest $sharzon_test)
    {
        if ($user->canDo('sharzon-test.sharzon_test.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $sharzon_test->user_id;
    }

    /**
     * Determine if the given user can delete the given sharzon_test.
     *
     * @param User $user
     * @param SharzonTest $sharzon_test
     *
     * @return bool
     */
    public function destroy(User $user, SharzonTest $sharzon_test)
    {
        if ($user->canDo('sharzon-test.sharzon_test.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $sharzon_test->user_id;
    }

    /**
     * Determine if the given user can verify the given sharzon_test.
     *
     * @param User $user
     * @param SharzonTest $sharzon_test
     *
     * @return bool
     */
    public function verify(User $user, SharzonTest $sharzon_test)
    {
        if ($user->canDo('sharzon-test.sharzon_test.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('sharzon-test.sharzon_test.verify') 
        && $user->is('manager')
        && $sharzon_test->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given sharzon_test.
     *
     * @param User $user
     * @param SharzonTest $sharzon_test
     *
     * @return bool
     */
    public function approve(User $user, SharzonTest $sharzon_test)
    {
        if ($user->canDo('sharzon-test.sharzon_test.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
