<?php

namespace SharzonTest\SharzonTest\Providers;

use Illuminate\Support\ServiceProvider;

class SharzonTestServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'sharzon-test');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'sharzon-test');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('sharzon-test', function ($app) {
            return $this->app->make('SharzonTest\SharzonTest\SharzonTest');
        });

        // Bind SharzonTest to repository
        $this->app->bind(
            \SharzonTest\SharzonTest\Interfaces\SharzonTestRepositoryInterface::class,
            \SharzonTest\SharzonTest\Repositories\Eloquent\SharzonTestRepository::class
        );

        $this->app->register(\SharzonTest\SharzonTest\Providers\AuthServiceProvider::class);
        $this->app->register(\SharzonTest\SharzonTest\Providers\EventServiceProvider::class);
        $this->app->register(\SharzonTest\SharzonTest\Providers\RouteServiceProvider::class);
        // $this->app->register(\SharzonTest\SharzonTest\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['sharzon-test'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('sharzon-test/sharzon-test.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/sharzon-test')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/sharzon-test')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
