<?php

namespace SharzonTest\SharzonTest\Workflow;

use SharzonTest\SharzonTest\Models\SharzonTest;
use Validator;

class SharzonTestValidator
{

    /**
     * Determine if the given sharzon_test is valid for complete status.
     *
     * @param SharzonTest $sharzon_test
     *
     * @return bool / Validator
     */
    public function complete(SharzonTest $sharzon_test)
    {
        return Validator::make($sharzon_test->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given sharzon_test is valid for verify status.
     *
     * @param SharzonTest $sharzon_test
     *
     * @return bool / Validator
     */
    public function verify(SharzonTest $sharzon_test)
    {
        return Validator::make($sharzon_test->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given sharzon_test is valid for approve status.
     *
     * @param SharzonTest $sharzon_test
     *
     * @return bool / Validator
     */
    public function approve(SharzonTest $sharzon_test)
    {
        return Validator::make($sharzon_test->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given sharzon_test is valid for publish status.
     *
     * @param SharzonTest $sharzon_test
     *
     * @return bool / Validator
     */
    public function publish(SharzonTest $sharzon_test)
    {
        return Validator::make($sharzon_test->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given sharzon_test is valid for archive status.
     *
     * @param SharzonTest $sharzon_test
     *
     * @return bool / Validator
     */
    public function archive(SharzonTest $sharzon_test)
    {
        return Validator::make($sharzon_test->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given sharzon_test is valid for unpublish status.
     *
     * @param SharzonTest $sharzon_test
     *
     * @return bool / Validator
     */
    public function unpublish(SharzonTest $sharzon_test)
    {
        return Validator::make($sharzon_test->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
